# Die 3 wichtigsten Checks in Google Search Console

> **Source:** [Antonio Blago](https://www.youtube.com/channel/UCoIBDdswc5VViHYPTKd0HwA) | **Duration:** 09:54 | **Published:** 20241217
> **URL:** [https://www.youtube.com/watch?v=QmSkrS5rytE](https://www.youtube.com/watch?v=QmSkrS5rytE)
> **Views:** 50 | **Likes:** 5

Eine Einführung in Google Search Console

In diesem Video gehe ich darauf ein, wie ich als SEO-Experte die Google Search Console einrichte, um einen Überblick über die Leistung einer Website zu erhalten. 
Ich zeige die wichtigsten Schritte und Funktionen der Search Console und erkläre, wie man die L...

---

## Table of Contents

- [Segment 1](#segment-1-00:00-02:00)
- [Segment 2](#segment-2-02:00-04:00)
- [Segment 3](#segment-3-04:00-06:00)
- [Segment 4](#segment-4-06:00-08:00)
- [Segment 5](#segment-5-08:00-09:54)

---

### Segment (00:00 - 02:00)

ja herzlich willkommen zu diesem ersten offiziellen Video in meinem YouTube-Kanal und hier möchte ich auf das Thema eingehen ähm was ich quasi als erstes mache als SEO bei einem Projekt und das ist die Google Search Konsole einrichten W mir da ein guten Überblick zu verschaffen über die aktuelle Situation und ich werde hier diesen Video zeigen was die wichtigsten drei Punkte sind die ich mir mal anschaue gleich zu anfangs in einem neuen Projekt und ja was ist überhaupt die Google Search Konsole weil es wahrscheinlich sehr viele von euch nicht kennen ähm oder nur mal gehört haben und zeige euch auch noch weiterführende Literatur Informationen wie ihr euch quasi eine Google Search Konsole anlegen könnt und da möchte ich erstmal drauf eingehen was ist die Google Search Konsole und Google ist in dem Sinne ja die Suchmaschine und wir können wir wissen ja alle dass wir hier z.B Suchanfragen stellen können aber wir wissen nicht was passiert eigentlich wenn man eine Suchanfrage stellt wer klickt auf meine Seite und diese ganzen Zahlen das können wir durch die Google Search Kole aufdecken also über die eigene Homepage und wenn ich jetzt z.B hier suche unify Super League und dann sehe ich jetzt hier z.B als erstes zu dem Suchbegriff dann den Spiel Artikel und äh Klick hier

---

### Segment (02:00 - 04:00)

Suchbegriff dann den Spiel Artikel und äh Klick hier drauf ähm dann äh kann äh und ich äh noch hier diese Kent auf jeden Fall ähm zustimme und hier auch lese den Artikel also hier scrolle damit Google merkt okay ich bin hier auch aktiv und der Artikel gefällt mir und ich klicke nicht gleich wieder weg dann wird es quasi als Klick gezählt und das kann Spiegel in Google Search Kole sehen wenn ich hier auf das Suchergebnis über das Keyword drauf klicke auf diesen Artikel und das will ich jetzt mal zeigen wie ihr das in dem Google Search Kole sehen könnt genau hier habe ich jetzt mein Beispiel m Projekt von mir offen und zwar ist es natürlich zensiert und äh die ersten drei Sachen die ich immer mache ist auf jeden Fall mir quasi die Performance anzuschauen also hier die Leistungsdaten also wie viele Klicks habe ich auf meiner Seite und das gilt immer für die domainne oder für die hinterlegte Seite und dann sehen wir schon mal ganz schnell okay in den letzten ähm 3 Monaten hier in diesen in dieser Schnellansicht ist äh der Traffic eher seitwärts gelaufen und ist natürlich jetzt nicht alarmierend aber auf jeden Fall kann man da noch mal reinschauen was da jetzt vielleicht nicht so gut läuft woh vielleicht mal noch mal Content pushchen können genau jetzt bin ich jetzt mir mal auf die search Kole auf die Performance Ansicht hier in dem Reiter gegangen und jetzt sehen wir jetzt schon mal hier die dre Monats

---

### Segment (04:00 - 06:00)

jetzt sehen wir jetzt schon mal hier die dre Monats Ansicht und ähm wir sehen jetzt die impressions also die äh Anzeigen äh der Suchergebnisse in dem Suchergebnissen also jetzt äh wo wir jetzt hier drauf waren ähm das sind quasi impressions ne also wenn du jetzt hier was suchst und dann deine Seite angezeigt wird das ist die impression und ähm wenn wir jetzt quasi auf einen Artikel drauf klicken dann ist es zählt es als Klick ähm aber nur dann wenn ich nicht sofort wieder zurückspringe sondern ähm der zählt der Klick zählt erst wenn ich genügend lang auf der Seite bin und zufriedenstellende nutzersignale für Google aussende dann zählt es hier als Klick und dann sehen wir schon ganz gut okay was ist die Verzehrung zwischen äh Suchergebnis Anzeige und Klicks und ähm daraus resultiert das weiteren sehen wir ja auch noch mal die durchschnittliche Position aller Keywords also ich habe das jetzt noch mal nicht gefiltert und dann sieht man auch für jedes Keyword hier unten welche Position das Keyword hat und sieht es auch im zeitlichen Verlauf ich habe jetzt hier die Position durchschnittliche Position markiert und wir sehen jetzt hier in der orangenen Linie ähm Position für jedes einzelne kivt und kann man auch jetzt hier im zeitlichen Verlauf sehen genau eine zweite Sache die ich mir immer auch anschaue ist die Indexierung also wie gut ist meine Seite in Google indexiert weil ohne Indexierung kannst du gar nicht hier in den äh Suchergebnissen auftauchen also ohne dass deine Seite hier

---

### Segment (06:00 - 08:00)

den äh Suchergebnissen auftauchen also ohne dass deine Seite hier in dem grünen Bereich ist also hier indexiert angezeigt ist wird sie in diesen Suchergebnissen nicht auftauchen insofern muss man hier immer das Verhältnis sehen zwischen indexiert und nicht indexiert da werden wir noch mal tiefer drauf eingehen welche Verhältnisse ganz gut sind und eher bedenklich aber es gibt sehr viele Möglichkeit warum deine Seite nicht indexiert wird das ist auf jeden Fall noch mal ein tiefgehenderes Thema aber nur mal für dich zu wissen wenn du jetzt z.B auf deine Seite gehst und du siehst hier nur drei Seiten sind grün und 100.000 Seiten sind nicht indexiert dann ist es natürlich sehr alarmierend weil deine Seite so gut wie gar nicht indexiert wird und nicht auf Google irgendwie auffindbar ist da solltest du auf jeden Fall Handeln ähm also je je mehr Grün du hier siehst desto besser äh und bei viel grau musst du auf jeden Fall handeln was natürlich auch immer sehr wichtig ist was ich mir auch immer sehr gerne anschaue ist die Core webweitles das ist in dem Sinne die Geschwindigkeit ähm äh oder die äh ja die Messung für Google ob eine domainne oder eine URL schnell genug Daten oder Seiten inliefert und äh hier siehst Du quasi wenn du jetzt viel Grün hast dann ist deine Seite schnell genug ähm wenn du jetzt natürlich gelb hast als Zeichen dass du Verbesserung hast und bei Rot solltest du natürlich sofort handeln weil Google ähm da zu viel Ladezeit hat und dann unter Umständen

---

### Segment (08:00 - 09:54)

ähm da zu viel Ladezeit hat und dann unter Umständen deine Seite nicht richtig crawen kann oder auch die Nutzer gegebenfalls auch abspringen wenn deine Seite zu Arl genau das weiteren ähm gibt's auch noch äh diesen sehr wichtigen Tab und zwar die Produkt äh und Merchant also händlerlistings und ähm das würde ich auch noch mal in einem Video besprechen genauer weil es wirürde jetzt den Rahmen sprengen ähm aber es ist auch noch mal ein sehr wichtiger äh Indikator wenn ihr jetzt ein E-Commerce Unternehmen seid oder ein onlineeshop habt dann solltet ihr auf jeden Fall hier schauen dass alle Eure Produkte äh angezeigt werden genau also ich hoffe ähm das Video hat euch soweit gefallen und ähm des Weiteren ähm habe ich hier noch ein paar ähm Tutorials die ich auch in der Beschreibung hinterlege also wie könnt ihr ein Google Konto einrichten also das ist sehr wichtig natürlich um ein Gole search Kole überhaupt einzurichten dass ihr ein Google Konto habt und ähm wenn ihr quasi ein Google Search Kole dann einrichten wollt dann habe ich hier auch noch mal eine Anleitung detailliert wie ihr es machen könnt und ähm dann habe ich noch ein Video wie ihr dann Person oder eure Team ähure Team Mitglieder auch zu Google Search Konsole hinzufügent genau also ich hoffe das Video war toll für euch und wir sehen uns beim nächsten Mal macht's gut ciao

---


*Transcript source: youtube_auto_generated*
*Confidence: 80%*